@@ -906,7 +906,7 @@ def contextual_analysis_profile(data, keyword_corpus, hashtag_corpus):
     tweets_df = keyword_score(tweets_df, sample_data_tokenized,keyword_corpus)
     tweets_df = hashtag_score(tweets_df,hashtag_corpus)	
     tweets_df["terrorist_suggestion"] = 0
-    tweets_df["terrorist_suggestion"][(tweets_df["hashtag_score"]>0) | (tweets_df["keyword_score"]>0.3)] = 1
+    tweets_df["terrorist_suggestion"][(tweets_df["hashtag_score"]>0) | (tweets_df["keyword_score"]>0)] = 1
     tweets_irr_words = len(tweets_df[tweets_df["terrorist_suggestion"]==1])
     if len(tweets_df[tweets_df["terrorist_suggestion"]==1]) == 0:
       data["per_hash_key"] = 0
@@ -1130,7 +1130,7 @@ def keyword_score(data,sample_data_tokenized, keyword_corpus):
 
 
 def terrorist_keywords_belonging(data):
-	temp = data[data['keyword_score']>0.3].reset_index(drop=True)
+	temp = data[data['keyword_score']>0].reset_index(drop=True)
 	# Draw plot
 	fig, ax = plt.subplots(figsize=(36,8), dpi= 80)
 	ax.vlines(x=temp.index, ymin=0, ymax=temp.keyword_score, color='firebrick', alpha=0.7, linewidth=2)
